==> smurf_0.52.5.orig.tar.gz: smurf-0.52.5/src/drivers/alsa.h <==
/*==================================================================
 * alsa.h - Header file for general ALSA stuff
 *
 * Smurf Sound Font Editor
 * Copyright (C) 1999-2001 Josh Green
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA or point your web browser to http://www.gnu.org.
 *
 * To contact the author of this program:
 * Email: Josh Green <jgreen@users.sourceforge.net>
 * Smurf homepage: http://smurf.sourceforge.net
 *==================================================================*/
#ifndef __ALSA_H__
#define __ALSA_H__

#include "config.h"

#ifdef ALSA_SUPPORT

#include <sys/asoundlib.h>

/* Oohhhh please, please, please release ALSA 1.0 :) */

#if SND_LIB_MAJOR > 0 || (SND_LIB_MINOR == 9 && SND_LIB_SUBMINOR >= 6)
#define NEW_ALSA_SEQ 1
#endif

#if SND_LIB_MAJOR > 0 || SND_LIB_MINOR == 9
#define NEW_ALSA 1
#endif

#endif /* #ifdef ALSA_SUPPORT */

#endif /* __ALSA_H__ */

==> smurf_0.52.6.orig.tar.gz: smurf-0.52.6/src/drivers/alsa.h <==
/*==================================================================
 * alsa.h - Header file for general ALSA stuff
 *
 * Smurf Sound Font Editor
 * Copyright (C) 1999-2001 Josh Green
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA or point your web browser to http://www.gnu.org.
 *
 * To contact the author of this program:
 * Email: Josh Green <jgreen@users.sourceforge.net>
 * Smurf homepage: http://smurf.sourceforge.net
 *==================================================================*/
#ifndef __ALSA_H__
#define __ALSA_H__

#include "config.h"

#ifdef ALSA_SUPPORT

#include <sys/asoundlib.h>

/* Oohhhh please, please, please release ALSA 1.0 :) */

/* what happened to SND_LIB_SUBMINOR? Its now 0 in CVS. We'll just force
   new sequencer interface with 0.9.0beta releases, but this will break older
   ones (Nov 1st, 2001) */

#if SND_LIB_MAJOR > 0 || SND_LIB_MINOR == 9
#define NEW_ALSA_SEQ 1
#endif

#if SND_LIB_MAJOR > 0 || SND_LIB_MINOR == 9
#define NEW_ALSA 1
#endif

#endif /* #ifdef ALSA_SUPPORT */

#endif /* __ALSA_H__ */
